@@ -173,15 +173,18 @@ gboolean db_set_binary_data_content(const gchar* binary_id, const gchar* content
     gchar* filepath = g_strconcat(dir_path, G_DIR_SEPARATOR_S, inner_binary_id, NULL);
     
     gboolean save_resilt = FALSE;
-
+    
+    gint content_size;
+    gchar* content_decoded;
+    content_decoded =  g_base64_decode(content, &content_size); 
     if (filepath != NULL) {
-        save_resilt = g_file_set_contents(filepath, content, -1, NULL);    
+        save_resilt = g_file_set_contents(filepath, content_decoded, content_size, NULL);    
     }    
-        
     g_free(filepath);
     g_free(inner_binary_id);
     g_free(dir_path);
     g_free(db_path);        
+    g_free(content_decoded);    
     return save_resilt;
 }
 
@@ -206,10 +209,13 @@ static gboolean save_node_content_to_file(const xmlNodePtr node, const gchar* fi
         return FALSE;
     }
 
-    gboolean save_result = g_file_set_contents(filepath, (const gchar*)content, -1, NULL);
-
+    gint content_size;
+    gchar* content_decoded;
+    content_decoded =  g_base64_decode(content, &content_size); 
+    gboolean save_result = g_file_set_contents(filepath, (const gchar*)content_decoded, content_size, NULL);
+     
     g_free(content);
-
+    g_free(content_decoded);
     
     if (save_result == TRUE && remove_content == TRUE) {
         xmlNodeSetContent(node, NULL);	
@@ -384,9 +390,9 @@ gint load_binary_data_to_doc(const gchar* schema_name, xmlDocPtr doc)
     
             gchar* content = NULL;
 
-            g_file_get_contents(filepath, &content, NULL, NULL);            
+//            g_file_get_contents(filepath, &content, NULL, NULL);            
 
-            xmlNodeSetContent(nodeset->nodeTab[i], BAD_CAST content);
+            xmlNodeSetContent(nodeset->nodeTab[i], BAD_CAST filepath);
             DB_P2DEBUG(3,"filepath = %s %s", filepath, content);                                      
                                       
             if (nodeset->nodeTab[i]->type != XML_NAMESPACE_DECL) {
