@@ -33,19 +33,6 @@ static void msa_connection_handler(ConIcConnection* connection, ConIcConnectionE
 static void msa_get_conic_settings(ConIcConnection* connection, gchar** proxy, gint* port);
 static void msa_set_driver_status(msa_module_status _status, gchar* proxy, gint port);
 //static int init_event_manager();
-/* Error Code */
-typedef enum error_type
-{
-    FAILURE = -1,
-    NO_ERRORS = 0,
-    SUCCESS = 0,
-    ERROR_ALLOCATION_OF_MEMORY,
-    ERROR_NO_DRIVER_FUNCTION,
-    ERROR_INITIALIZATION_ALREADY_PASSED,
-    ERROR_DRIVER_IS_BUSY,
-    ERROR_CANT_SEND_DATA,
-    ERROR_CANT_PARSE_DATA
-} error_type ;
 
 #endif
 
