@@ -151,7 +151,8 @@ static int start_connection()
     /** Connect signal to receive connection events **/
     g_signal_connect(G_OBJECT(connection), "connection-event", 
                      G_CALLBACK(msa_connection_handler), NULL);
-
+    /* Set automatic events */
+        g_object_set(G_OBJECT(connection), "automatic-connection-events", TRUE, NULL);
     /** Request connection and check for the result **/
     success = con_ic_connection_connect(connection, CON_IC_CONNECT_FLAG_NONE);
     if (!success) 
