@@ -1019,7 +1019,6 @@ gboolean ui_driver_get_settings(gpointer ptr_reqXml)
 
     xmlNodePtr rootNode;
     xmlNodePtr node;
-    char* driver_id;
     GtkWidget* entries[4];
     int i = 0;
     
@@ -1030,7 +1029,7 @@ gboolean ui_driver_get_settings(gpointer ptr_reqXml)
     
     // Получаем имя источника
     node = node_search(rootNode, "SourceID");
-    driver_id = xmlNodeGetContent(node);
+    //g_char *driver_id = xmlNodeGetContent(node);
  
     //g_debug("ui_dirver_get_settings: %s", driver_id);
     
@@ -1139,7 +1138,7 @@ gboolean ui_show_info(gpointer request)
     }
     
     if (show) {
-        hildon_banner_show_information(ui_data->window, NULL, text);
+        hildon_banner_show_information(ui_data->window, NULL, _(text));
     } else {
         hildon_banner_show_information(ui_data->window, NULL, DB_SAVE_MESSAGE_FRIENDS_PROFILE_TEXT);
     }
@@ -1232,7 +1231,7 @@ gboolean ui_show_error(gpointer request)
         show = FALSE;
     }
     if(show)
-        hildon_banner_show_information(ui_data->window, NULL, text);
+        hildon_banner_show_information(ui_data->window, NULL, _(text));
     //hildon_gtk_window_set_progress_indicator (ui_data->window, 0);
     xmlFreeDoc(request);
     g_free(code);
